==> snack_1.6.orig.tar.gz: snack-1.6.orig/demos/Waveform.tcl <==
#!/bin/sh
# the next line restarts using wish \
exec wish8.0 "$0" "$@"

package require -exact snack 1.6

set width 400
set height 100
set pps 300
set color black
set stipple ""
set filename waveform.ps
option add *font {Helvetica 10 bold}

pack [ canvas .c -width 600 -height 200]
pack [ label .l -text "Drag waveform with left mouse button"]
pack [ frame .f1] -pady 2
pack [ scale .f1.s1 -variable width -label width -from 10 -to 600 \
	-orient hori -length 150 -command {.c itemconf wave -width }] -side left
pack [ scale .f1.s2 -variable height -label height -from 10 -to 200 \
	-orient hori -length 150 -command {.c itemconf wave -height }] -side left
pack [ scale .f1.s3 -variable pps -label Pix/sec -from 10 -to 600 \
	-orient hori -length 150 -command {.c itemconf wave -pixels }] -side left

pack [ frame .f2] -pady 2
pack [ checkbutton .f2.z -text Zerolevel -variable zerol \
	-command {.c itemconf wave -zerolevel $zerol}] -side left
pack [ checkbutton .f2.f -text Frame -variable frame \
	-command {.c itemconf wave -frame $frame}] -side left

foreach f {Black Red Blue} {
    pack [ radiobutton .f2.c$f -text $f -variable color -value $f \
	    -command {.c itemconf wave -fill $color}] -side left
}

pack [ radiobutton .f2.s100 -text 100% -variable stipple -value "" \
	-command {.c itemconf wave -stipple $stipple}] -side left
pack [ radiobutton .f2.s50 -text 50% -variable stipple -value gray50 \
	-command {.c itemconf wave -stipple $stipple}] -side left
pack [ radiobutton .f2.s25 -text 25% -variable stipple -value gray25 \
	-command {.c itemconf wave -stipple $stipple}] -side left

pack [ frame .f3] -pady 2
pack [ button .f3.br -bitmap record -command Record -fg red] -side left
pack [ button .f3.bs -bitmap stop -command {s stop}] -side left
pack [ label .f3.l -text "Load sound file:"] -side left
pack [ button .f3.b1 -text ex1.wav -command {s read ex1.wav}] -side left
pack [ button .f3.b2 -text ex2.wav -command {s read ex2.wav}] -side left

proc Record {} {
    .c itemconf wave -pixelspersecond 300 -width 300
    s record
    after 10000 {.f3.bs invoke}
}

pack [ frame .f4] -pady 2
pack [ label .f4.l -text "Generate postscript file:"] -side left
pack [ entry .f4.e -text filename] -side left
pack [ button .f4.b -text Save -command {.c postscript -file $filename}] -side left

pack [ button .bExit -text Exit -command exit]

sound s -load ex1.wav

update

.c create waveform 300 100 -anchor c -sound s -height $height -tags wave -debug 0 -zerolevel 0

source widutil.tcl
BindDrag .c

==> snack1.7.0.tar.gz: snack1.7.0/demos/Waveform.tcl <==
#!/bin/sh
# the next line restarts using wish \
exec wish8.3 "$0" "$@"

package require -exact snack 1.7

set width 400
set height 100
set pps 300
set color black
set stipple ""
set filename waveform.ps
option add *font {Helvetica 10 bold}

pack [ canvas .c -width 600 -height 200]
pack [ label .l -text "Drag waveform with left mouse button"]
pack [ frame .f1] -pady 2
pack [ scale .f1.s1 -variable width -label Width -from 10 -to 600 \
	-orient hori -length 150 -command {.c itemconf wave -width }] -side left
pack [ scale .f1.s2 -variable height -label Height -from 10 -to 200 \
	-orient hori -length 150 -command {.c itemconf wave -height }] -side left
pack [ scale .f1.s3 -variable pps -label Pix/sec -from 10 -to 600 \
	-orient hori -length 150 -command {.c itemconf wave -pixels }] -side left

pack [ frame .f2] -pady 2
pack [ checkbutton .f2.z -text Zerolevel -variable zerol \
	-command {.c itemconf wave -zerolevel $zerol}] -side left
pack [ checkbutton .f2.f -text Frame -variable frame \
	-command {.c itemconf wave -frame $frame}] -side left

foreach f {Black Red Blue} {
    pack [ radiobutton .f2.c$f -text $f -variable color -value $f \
	    -command {.c itemconf wave -fill $color}] -side left
}

pack [ radiobutton .f2.s100 -text 100% -variable stipple -value "" \
	-command {.c itemconf wave -stipple $stipple}] -side left
pack [ radiobutton .f2.s50 -text 50% -variable stipple -value gray50 \
	-command {.c itemconf wave -stipple $stipple}] -side left
pack [ radiobutton .f2.s25 -text 25% -variable stipple -value gray25 \
	-command {.c itemconf wave -stipple $stipple}] -side left

pack [ frame .f3] -pady 2
pack [ button .f3.br -bitmap snackRecord -command Record -fg red] -side left
pack [ button .f3.bs -bitmap snackStop -command {s stop}] -side left
pack [ label .f3.l -text "Load sound file:"] -side left
pack [ button .f3.b1 -text ex1.wav -command {s read ex1.wav}] -side left
pack [ button .f3.b2 -text ex2.wav -command {s read ex2.wav}] -side left

proc Record {} {
    .c itemconf wave -pixelspersecond 300 -width 300
    s record
    after 10000 {.f3.bs invoke}
}

pack [ frame .f4] -pady 2
pack [ label .f4.l -text "Generate postscript file:"] -side left
pack [ entry .f4.e -text filename] -side left
pack [ button .f4.b -text Save -command {.c postscript -file $filename}] -side left

pack [ button .bExit -text Exit -command exit]

snack::sound s -load ex1.wav

update

.c create waveform 300 100 -anchor c -sound s -height $height -tags wave -debug 0 -zerolevel 0

source widutil.tcl
BindDrag .c
